pub struct Snake {
pub x0: isize,
pub y0: isize,
pub len: isize,
}Expand description
A pair of spans with the same content in two different slices.
Fields
x0: isizeThe start of the span in the removed bytes.
y0: isizeThe start of the span in the added bytes.
len: isizeThe length of the span.